@@ -4,6 +4,7 @@ class GlobalVars:
         self._tick_rate = -1
         self._delta_time = -1
         self._instid = 100000
+        self._boss1_death = 0
 
     @property
     def screen_size(self):
@@ -40,3 +41,15 @@ class GlobalVars:
     def getid(self):
         self._instid += 1
         return self._instid - 1
+
+    def set_FX_vol(self, volume):
+        self.FXVol = volume
+
+    def set_music_vol(self, volume):
+        self.musicVol = volume
+
+    def get_FX_vol(self):
+        return self.FXVol
+    
+    def get_music_vol(self):
+        return self.musicVol
