@@ -1,4 +1,4 @@
-from bluebeam.objects import Target
+from objects import Target
 import pygame
 
 
