@@ -1,5 +1,5 @@
 import pygame
-from bluebeam.objects import Bullet
+from objects import Bullet
 import os
 
 
@@ -12,6 +12,7 @@ class PlayerBullet(Bullet):
         self.dmg = 10
         self._objid = 4
         self.charged = False
+        self.depth = 16
         self.rapid_fire = False
         self.sourceDir = os.path.dirname(os.path.abspath(__file__))
         self.imageDir = os.path.join(os.path.dirname(self.sourceDir), "images")
