@@ -1,4 +1,4 @@
-from bluebeam.objects import Enemy
+from objects import Enemy
 import pygame
 
 
