@@ -1,4 +1,4 @@
-from bluebeam.objects import WhaleTurret
+from objects import WhaleTurret
 import pygame
 
 
