@@ -13,13 +13,18 @@ from .Target import Target
 from .BadTarget import BadTarget
 from .SliderEnemy import SliderEnemy
 from .ShootyEnemy import ShootyEnemy
+from .BulkyEnemy import BulkyEnemy
 # Enemy Projectiles
 from .EnemyBullet import EnemyBullet
+from .SuperEnemyBullet import SuperEnemyBullet
 from .Rocket import Rocket
+from .HomingRocket import HomingRocket
 from .Laser import Laser
 from .SplitBomb import SplitBomb
+from .WaveBomb import WaveBomb
 from .Shockwave import Shockwave
 from .Explosion import Explosion
+from .Tentacle import Tentacle
 # Boss 1 Parts
 from .WhaleTurret import WhaleTurret
 from .WhaleCore import WhaleCore
@@ -33,7 +38,21 @@ from .WhaleTurretLaser import WhaleTurretLaser
 
 from .AlphaWhale import AlphaWhale
 
+# Boss 2
+from .SpireBody import SpireBody
+from .BetaSpire import BetaSpire
+# Boss 3
+from .GammaGenerator import GammaGenerator
+from .GammaHand import GammaHand
+from .GammaHead import GammaHead
+from .GammaBGRocket import GammaBGRocket
+from .GammaCore import GammaCore
+# Triggers
 from .BossSpawnTrigger import BossSpawnTrigger
+from .BetaBossSpawnTrigger import BetaBossSpawnTrigger
+from .GammaBossSpawnTrigger import GammaBossSpawnTrigger
+
+from .LittleGrey import LittleGrey
 
 #PowerUps
 from .YellowPower import YellowPower
